commit 4223f07877c02c6ab9e4ef8d1c324496bbb9708a
Author: Simon Riggs <simon.riggs@enterprisedb.com>
Date:   Wed Dec 22 11:27:10 2021 +0000

    Copy editing on docs and resolve a couple of XXX comments

diff --git a/doc/src/sgml/ref/merge.sgml b/doc/src/sgml/ref/merge.sgml
index 89cf2d4443..ed5228fba1 100644
--- a/doc/src/sgml/ref/merge.sgml
+++ b/doc/src/sgml/ref/merge.sgml
@@ -98,16 +98,15 @@ DELETE
   </para>
 
   <para>
-   There is no <literal>MERGE</literal> privilege.
-   You must have the <literal>UPDATE</literal> privilege on the column(s)
+   There is no separate <literal>MERGE</literal> privilege.
+   If you specify an update action, you must have the
+   <literal>UPDATE</literal> privilege on the column(s)
    of the <replaceable class="parameter">target_table_name</replaceable>
-   referred to in the <literal>SET</literal> clause
-   if you specify an update action, the <literal>INSERT</literal> privilege
-   on the <replaceable class="parameter">target_table_name</replaceable>
-   if you specify an insert action and/or the <literal>DELETE</literal>
-   privilege on the <replaceable class="parameter">target_table_name</replaceable>
-   if you specify a delete action on the
-   <replaceable class="parameter">target_table_name</replaceable>.
+   that are referred to in the <literal>SET</literal> clause.
+   If you specify an insert action, you must have the <literal>INSERT</literal>
+   privilege on the <replaceable class="parameter">target_table_name</replaceable>.
+   If you specify an delete action, you must have the <literal>DELETE</literal>
+   privilege on the <replaceable class="parameter">target_table_name</replaceable>.
    Privileges are tested once at statement start and are checked
    whether or not particular <literal>WHEN</literal> clauses are executed.
    You will require the <literal>SELECT</literal> privilege on the
@@ -118,9 +117,9 @@ DELETE
 
   <para>
    <command>MERGE</command> is not supported if the
-   <replaceable class="parameter">target_table_name</replaceable> has
-   <literal>RULES</literal> defined on it.
-   See <xref linkend="rules"/> for more information about <literal>RULES</literal>.
+   <replaceable class="parameter">target_table_name</replaceable> is a
+   materialized view, foreign table or if it has any
+   <literal>RULEs</literal> defined on it.
   </para>
  </refsect1>
 
diff --git a/src/backend/parser/parse_merge.c b/src/backend/parser/parse_merge.c
index 59d0722688..32a19ee024 100644
--- a/src/backend/parser/parse_merge.c
+++ b/src/backend/parser/parse_merge.c
@@ -344,10 +344,10 @@ transformMergeStmt(ParseState *pstate, MergeStmt *stmt)
 	qry->rtable = pstate->p_rtable;
 
 	/*
-	 * XXX MERGE is unsupported in various cases
+	 * MERGE is unsupported in various cases
 	 */
 	if (pstate->p_target_relation->rd_rel->relkind != RELKIND_RELATION &&
-		  pstate->p_target_relation->rd_rel->relkind != RELKIND_PARTITIONED_TABLE)
+		pstate->p_target_relation->rd_rel->relkind != RELKIND_PARTITIONED_TABLE)
 		ereport(ERROR,
 				(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
 				 errmsg("MERGE is not supported for this relation type")));
@@ -508,7 +508,7 @@ transformMergeStmt(ParseState *pstate, MergeStmt *stmt)
 
 	qry->mergeActionList = mergeActionList;
 
-	/* XXX maybe later */
+	/* RETURNING could potentially be added in the future, but not in SQL Std */
 	qry->returningList = NULL;
 
 	qry->hasTargetSRFs = false;
